pub struct IndexState { /* private fields */ }Implementations
Sourceimpl IndexState
impl IndexState
pub fn apply(&mut self, entry: IndexEntry) -> Result<(), DbError>
pub fn unique_lookup( &self, collection_id: u32, index_name: &str, index_key: &[u8], ) -> Option<&[u8]>
pub fn non_unique_lookup( &self, collection_id: u32, index_name: &str, index_key: &[u8], ) -> Option<Vec<Vec<u8>>>
Sourcepub fn non_unique_range_lookup(
&self,
collection_id: u32,
index_name: &str,
lo: Option<&ScalarValue>,
lo_inclusive: bool,
hi: Option<&ScalarValue>,
hi_inclusive: bool,
) -> Vec<Vec<u8>>
pub fn non_unique_range_lookup( &self, collection_id: u32, index_name: &str, lo: Option<&ScalarValue>, lo_inclusive: bool, hi: Option<&ScalarValue>, hi_inclusive: bool, ) -> Vec<Vec<u8>>
Collect PK keys for all index entries whose key falls in [lo, hi] (per scalar_partial_cmp).
Sourcepub fn unique_range_lookup(
&self,
collection_id: u32,
index_name: &str,
lo: Option<&ScalarValue>,
lo_inclusive: bool,
hi: Option<&ScalarValue>,
hi_inclusive: bool,
) -> Vec<Vec<u8>>
pub fn unique_range_lookup( &self, collection_id: u32, index_name: &str, lo: Option<&ScalarValue>, lo_inclusive: bool, hi: Option<&ScalarValue>, hi_inclusive: bool, ) -> Vec<Vec<u8>>
Collect PK keys for unique index entries whose key falls in [lo, hi].